AFRL labeling Info (sarpy.annotation.afrl_elements.Research)
============================================================

.. automodule:: sarpy.annotation.afrl_elements.Research
    :members:
    :show-inheritance:
    :inherited-members:
